@@ -5,7 +5,7 @@ import os
 import numpy as np
 import pandas as pd
 from .stats import gfevd, mbcs_index, nhd, mdd
-from .mcmc import mcmc, tmcmc
+from .mcmc import mcmc
 from .filtering import *
 from .tools import *
 from .mpile import *
@@ -126,8 +126,11 @@ def save_meta(self, filename=None, verbose=True):
             exec("self.fdict[o] = self." + str(o))
 
     if hasattr(self, "filter"):
-        self.fdict["filter_R"] = self.filter.R
-        self.fdict["filter_P"] = self.filter.P
+        try:
+            self.fdict["filter_R"] = self.filter.R
+            self.fdict["filter_P"] = self.filter.P
+        except:
+            pass
 
     np.savez_compressed(filename, **self.fdict)
 
@@ -183,13 +186,16 @@ def load_rdict(self, path=None, suffix=""):
     return dict(np.load(path, allow_pickle=True))
 
 
-def traceplot_m(self, chain=None, **args):
+def traceplot_m(self, chain=None, prior_names=None, **args):
 
     if chain is None:
         chain = self.get_chain()
         args["tune"] = self.get_tune
 
-    return ew.traceplot(chain, varnames=self.fdict["prior_names"], **args)
+    if prior_names is None:
+        prior_names = self.fdict["prior_names"]
+
+    return ew.traceplot(chain, varnames=prior_names, **args)
 
 
 def posteriorplot_m(self, **args):
@@ -365,7 +371,6 @@ DSGE_RAW.k_map = k_map
 DSGE_RAW.traj = traj
 # from mcmc
 DSGE_RAW.mcmc = mcmc
-DSGE_RAW.tmcmc = tmcmc
 # from estimation
 DSGE_RAW.prep_estim = prep_estim
 DSGE_RAW.load_estim = prep_estim
