@@ -88,7 +88,7 @@ def prior_sampler(
 
     self.debug |= debug
 
-    if hasattr(self, "pool"):
+    if not debug and hasattr(self, "pool"):
 
         from .estimation import create_pool
         create_pool(self)
